@@ -291,7 +291,7 @@ test_that("survival probabilities functions work for PAM", {
 
 })
 
-test_that("CIF works", {
+test_that("CIF works with pamm", {
 
   set.seed(211758)
   df <- data.frame(time = rexp(20), status = sample(c(0,1, 2), 20, replace = TRUE))
@@ -312,6 +312,49 @@ test_that("CIF works", {
 
 })
 
+test_that("CIF works with mgcv::gam", {
+  
+  set.seed(211758)
+  df <- data.frame(time = rexp(20), status = sample(c(0,1, 2), 20, replace = TRUE))
+  ped_cr <- as_ped(df, Surv(time, status)~., id = "id") %>%
+    mutate(cause = as.factor(cause))
+  pam <- gam(ped_status ~ s(tend, by = cause), data = ped_cr, family = poisson(), offset = offset)
+  ndf <- ped_cr %>%
+    make_newdata(tend = unique(tend), cause = unique(cause)) %>%
+    group_by(cause) %>%
+    add_cif(pam)
+  expect_data_frame(ndf, nrows = 26L, ncols = 11L)
+  expect_subset(c("cif", "cif_lower", "cif_upper"), colnames(ndf))
+  expect_true(all(ndf$cif < ndf$cif_upper))
+  expect_true(all(ndf$cif > ndf$cif_lower))
+  expect_true(all(ndf$cif <= 1 & ndf$cif >= 0))
+  expect_true(all(ndf$cif_lower <= 1 & ndf$cif_lower >= 0))
+  expect_true(all(ndf$cif_upper <= 1 & ndf$cif_upper >= 0))
+  
+})
+
+
+test_that("CIF works with character causes", {
+  
+  set.seed(211758)
+  df <- data.frame(time = rexp(20), status = sample(c(0,1, 2), 20, replace = TRUE))
+  ped_cr <- as_ped(df, Surv(time, status)~., id = "id") %>%
+    mutate(cause = factor(cause, labels = c("Death", "Discharge")))
+  pam <- pamm(ped_status ~ s(tend, by = cause), data = ped_cr)
+  ndf <- ped_cr %>%
+    make_newdata(tend = unique(tend), cause = unique(cause)) %>%
+    group_by(cause) %>%
+    add_cif(pam)
+  expect_data_frame(ndf, nrows = 26L, ncols = 11L)
+  expect_subset(c("cif", "cif_lower", "cif_upper"), colnames(ndf))
+  expect_true(all(ndf$cif < ndf$cif_upper))
+  expect_true(all(ndf$cif > ndf$cif_lower))
+  expect_true(all(ndf$cif <= 1 & ndf$cif >= 0))
+  expect_true(all(ndf$cif_lower <= 1 & ndf$cif_lower >= 0))
+  expect_true(all(ndf$cif_upper <= 1 & ndf$cif_upper >= 0))
+  
+})
+
 test_that("Transition Probability works", {
   
   ndf <- ped_msm %>%
